==> openjdk-13_13~17.orig.tar.xz: openjdk-13-13~17/src/hotspot/share/gc/g1/g1SharedDirtyCardQueue.hpp <==
/*
 * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_GC_G1_G1SHAREDDIRTYCARDQUEUE_HPP
#define SHARE_GC_G1_G1SHAREDDIRTYCARDQUEUE_HPP

#include "utilities/globalDefinitions.hpp"

class G1DirtyCardQueueSet;

// A dirty card queue providing thread-safe enqueue.  A shared global
// instance can be used for cases where a thread-local dirty card can't
// be used.
class G1SharedDirtyCardQueue {
  G1DirtyCardQueueSet* const _qset;
  void** _buffer;
  size_t _index;

  // Noncopyable
  G1SharedDirtyCardQueue(const G1SharedDirtyCardQueue&);
  G1SharedDirtyCardQueue& operator=(const G1SharedDirtyCardQueue&);

public:
  G1SharedDirtyCardQueue(G1DirtyCardQueueSet* qset);
  ~G1SharedDirtyCardQueue();    // flushes the queue.

  // Thread-safe addition to shared logging buffer.
  void enqueue(void* card_ptr);

  // Flush any pending entries to the qset and remove the buffer.
  // Not thread-safe.
  void flush();

  // Discard any pending entries.
  // Not thread-safe.
  void reset();
};

#endif // SHARE_GC_G1_G1SHAREDDIRTYCARDQUEUE_HPP

==> openjdk-17_17.0.16+8.orig.tar.xz: openjdk-17-17.0.16+8/src/hotspot/share/gc/g1/g1SharedDirtyCardQueue.hpp <==
/*
 * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_GC_G1_G1SHAREDDIRTYCARDQUEUE_HPP
#define SHARE_GC_G1_G1SHAREDDIRTYCARDQUEUE_HPP

#include "utilities/globalDefinitions.hpp"

class G1DirtyCardQueueSet;

// A dirty card queue providing thread-safe enqueue.  A shared global
// instance can be used for cases where a thread-local dirty card can't
// be used.
class G1SharedDirtyCardQueue {
  G1DirtyCardQueueSet* const _qset;
  void** _buffer;
  size_t _index;

  NONCOPYABLE(G1SharedDirtyCardQueue);

public:
  G1SharedDirtyCardQueue(G1DirtyCardQueueSet* qset);
  ~G1SharedDirtyCardQueue();    // flushes the queue.

  // Thread-safe addition to shared logging buffer.
  void enqueue(void* card_ptr);

  // Flush any pending entries to the qset and remove the buffer.
  // Not thread-safe.
  void flush();

  // Discard any pending entries.
  // Not thread-safe.
  void reset();
};

#endif // SHARE_GC_G1_G1SHAREDDIRTYCARDQUEUE_HPP
